==> tine20-allinone_2020.08.8.tar.bz2: ActiveSync/js/ActiveSync-lang-en_NZ-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-29 03:29+0000\nLast-Translator: Ingo Ratsdorf\nLanguage-Team: English (New Zealand) (http://www.transifex.com/tine20/tine20/language/en_NZ/)\nLanguage: en_NZ\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Default Address book"
: ""

, "The default address book to create new contacts in."
: ""

, "Default Calendar"
: "Default calendar"

, "The default calendar to create new events in."
: "The default calendar for new events"

, "Default Task List"
: "Default task list"

, "The default task list to create new tasks in."
: "The default task list for new tasks"

, "Sync Devices"
: "Sync Devices"

, "Device ID"
: "Device ID"

, "Devicetype"
: "Device ype"

, "Owner"
: "Owner"

, "Policy"
: "Policy"

, "ActiveSync Version"
: ""

, "User agent"
: ""

, "Model"
: "Model"

, "IMEI"
: "IMEI"

, "Friendly Name"
: "Friendly name"

, "OS"
: "OS"

, "OS Language"
: "OS language"

, "Phonenumber"
: "Phone number"

, "Sync Device, Sync Devices"
: [
  ""
 ,""

]
, "Device, Devices"
: [
  "Device"
 ,"Devices"

]
, "Devices"
: "Devices"

, "Active Sync"
: "ActiveSync"

, "Select a Device"
: "Select a device"

, "No ActiveSync Device registered"
: "No ActiveSync device registered"

, "Set as {0} Filter"
: "Set as {0} filter"

, "Resetted Sync Filter"
: "Sync filter reset"

, "{0} filter for device \"{1}\" is now \"{2}\""
: "{0} filter for device \"{1}\" is now \"{2}\""

, "resetted"
: "reset"

, "Set Sync Filter"
: "Set sync filter"

, "ID"
: "ID"

, "Device Type"
: ""

, "Operating System"
: ""

, "Phone Number"
: ""

, "Ping Lifetime"
: "Ping lifetime"

, "Ping Folder"
: "Ping folder"

, "Remote Wipe"
: "Remote wipe"

, "Calendar Filter"
: ""

, "Contacts Filter"
: ""

, "E-mail Filter"
: ""

, "Tasks Filter"
: ""

, "Last Ping"
: "Last ping"

, "Monitor Last Ping"
: ""

, "Remote Device Reset"
: ""

, "Please Confirm"
: "Please Confirm"

, "Do you really want to wipe the selected devices? All personal data will be removed and the device will be reset to factory settings!"
: ""

, "Quicksearch"
: "Quicksearch"

, "Default Policy"
: "Default policy"

, "Default Policy installed during setup"
: "Default policy installed during setup"

, "Default policy for new devices"
: "Default policy for new devices"

, "Enter the id of the policy to apply to newly created devices."
: "Enter the policy ID to apply to newly created devices."

, "User Agent Deny List"
: ""

, "Array of regular expressions of User-Agent strings"
: ""

, "Disable Access Log"
: "Disable access log"

, "Disable ActiveSync Access Log creation."
: "Disable ActiveSync access log creation."

, "Filter timeslot for e-mails"
: ""

, "For how long in the past the e-mails should be synchronized."
: ""

, "Filter timeslot for events"
: "Filter timeslot for events"

, "For how long in the past the events should be synchronized."
: "For how long into the past the events should be synchronized for."

, "Manage ActiveSync devices"
: "Manage ActiveSync devices"

, "See, edit and delete ActiveSync devices"
: "Show, edit and delete ActiveSync devices"

, "Reset ActiveSync devices"
: "Reset ActiveSync devices"

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: "Remotely reset ActiveSync devices to factory state, deleting all data"














, "Sync Device"
: ""

, "Device"
: "Device"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: ActiveSync/js/ActiveSync-lang-en_NZ-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:43+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: English (New Zealand) (http://www.transifex.com/tine20/tine20/language/en_NZ/)\nLanguage: en_NZ\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Active Sync"
: "ActiveSync"

, "Select a Device"
: "Select a device"

, "No ActiveSync Device registered"
: "No ActiveSync device registered"

, "Set as {0} Filter"
: "Set as {0} filter"

, "Resetted Sync Filter"
: "Sync filter reset"

, "{0} filter for device \"{1}\" is now \"{2}\""
: "{0} filter for device \"{1}\" is now \"{2}\""

, "resetted"
: "reset"

, "Set Sync Filter"
: "Set sync filter"

, "Sync Devices"
: "Sync Devices"

, "ID"
: "ID"

, "Device ID"
: "Device ID"

, "Device Type"
: ""

, "Owner"
: "Owner"

, "Policy"
: "Policy"

, "ActiveSync Version"
: ""

, "User agent"
: ""

, "Model"
: "Model"

, "IMEI"
: "IMEI"

, "Friendly Name"
: "Friendly name"

, "Operating System"
: ""

, "OS Language"
: "OS language"

, "Phone Number"
: ""

, "Ping Lifetime"
: "Ping lifetime"

, "Ping Folder"
: "Ping folder"

, "Remote Wipe"
: "Remote wipe"

, "Calendar Filter"
: ""

, "Contacts Filter"
: ""

, "E-mail Filter"
: ""

, "Tasks Filter"
: ""

, "Last Ping"
: "Last ping"

, "Monitor Last Ping"
: ""

, "Remote Device Reset"
: ""

, "Please Confirm"
: "Please Confirm"

, "Do you really want to wipe the selected devices? All personal data will be removed and the device will be reset to factory settings!"
: ""

, "Quicksearch"
: "Quicksearch"

, "Sync Device, Sync Devices"
: [
  ""
 ,""

]
, "Device, Devices"
: [
  "Device"
 ,"Devices"

]
, "Devices"
: "Devices"

, "Devicetype"
: "Device ype"

, "OS"
: "OS"

, "Phonenumber"
: "Phone number"

, "Default Address book"
: ""

, "The default address book to create new contacts in."
: ""

, "Default Calendar"
: "Default calendar"

, "The default calendar to create new events in."
: "The default calendar for new events"

, "Default Task List"
: "Default task list"

, "The default task list to create new tasks in."
: "The default task list for new tasks"

, "Default policy for new devices"
: "Default policy for new devices"

, "Enter the id of the policy to apply to newly created devices."
: "Enter the policy ID to apply to newly created devices."

, "Device Model Agent Deny List"
: ""

, "Array of regular expressions of Device-Model strings"
: ""

, "User Agent Deny List"
: ""

, "Array of regular expressions of User-Agent strings"
: ""

, "Disable Access Log"
: "Disable access log"

, "Disable ActiveSync Access Log creation."
: "Disable ActiveSync access log creation."

, "Filter timeslot for e-mails"
: ""

, "For how long in the past the e-mails should be synchronized."
: ""

, "Filter timeslot for events"
: "Filter timeslot for events"

, "For how long in the past the events should be synchronized."
: "For how long into the past the events should be synchronized for."

, "%1$s ActiveSync failure"
: ""

, "Dear user,"
: ""

, "%1$s has noticed that the syncronization with your ActiveSync device is no longer active. Please trigger the syncronisation on your device."
: ""

, "Thank you."
: ""

, "Your %1$s Team"
: ""

, "Default Policy"
: "Default policy"

, "Default Policy installed during setup"
: "Default policy installed during setup"

, "Manage ActiveSync devices"
: "Manage ActiveSync devices"

, "See, edit and delete ActiveSync devices"
: "Show, edit and delete ActiveSync devices"

, "Reset ActiveSync devices"
: "Reset ActiveSync devices"

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: "Remotely reset ActiveSync devices to factory state, deleting all data"














, "Sync Device"
: ""

, "Device"
: "Device"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
